@@ -241,7 +241,7 @@ class BaseBoard:
             Pin name.
         type:
             File type used to save ``x`` to disk. May be "csv", "arrow", "parquet",
-            "joblib", or "file".
+            "joblib", "json", or "file".
         title:
             A title for the pin; most important for shared boards so that others
             can understand what the pin contains. If omitted, a brief description
@@ -302,7 +302,7 @@ class BaseBoard:
                 # note that we only raise an error if version path is a subdir
                 # of the pin path.
                 raise PinsError(
-                    "Attempting to write pin version to {dst_version_path}, "
+                    f"Attempting to write pin version to {dst_version_path}, "
                     "but that directory already exists."
                 )
 
